==> logtalk-3.88.0.tar.bz2: logtalk-3.88.0/examples/hooks/NOTES.md <==
---
jupyter:
  jupytext:
    text_representation:
      extension: .md
      format_name: markdown
      format_version: '1.1'
      jupytext_version: 1.16.6
  kernelspec:
    display_name: Logtalk
    language: logtalk
    name: logtalk_kernel
---

<!--
________________________________________________________________________

This file is part of Logtalk <https://logtalk.org/>  
SPDX-FileCopyrightText: 1998-2025 Paulo Moura <pmoura@logtalk.org>  
SPDX-License-Identifier: Apache-2.0

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
________________________________________________________________________
-->

# hooks

This folder contains a very simple example of using the Logtalk compiler 
hook support to (1) expand abbreviations in `info/1` directives; (2) convert
`write/1` goals into `write_term/3` goals where the terms written are quoted
and pre-processed by using `numbervars/3`.

Start by loading the example:

```logtalk
logtalk_load(hooks(loader)).
```

Check the XML documenting file generated for `object` for the results of the
`term_expansion/2` calls


Check the results of the `goal_expansion/2` calls:

```logtalk
object::out.
```

<!--
'A'
x(A, A)
3
true.
-->

==> logtalk-3.96.0.tar.bz2: logtalk-3.96.0/examples/hooks/NOTES.md <==
---
jupyter:
  jupytext:
    text_representation:
      extension: .md
      format_name: markdown
      format_version: '1.3'
      jupytext_version: 1.16.7
  kernelspec:
    display_name: Logtalk
    language: logtalk
    name: logtalk_kernel
---

<!--
________________________________________________________________________

This file is part of Logtalk <https://logtalk.org/>  
SPDX-FileCopyrightText: 1998-2025 Paulo Moura <pmoura@logtalk.org>  
SPDX-License-Identifier: Apache-2.0

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
________________________________________________________________________
-->

# hooks

This folder contains a very simple example of using the Logtalk compiler 
hook support to (1) expand abbreviations in `info/1` directives; (2) convert
`write/1` goals into `write_term/3` goals where the terms written are quoted
and pre-processed by using `numbervars/3`.

Print Logtalk, Prolog backend, and kernel versions (if running as a notebook):

```logtalk
%versions
```

Start by loading the example:

```logtalk
logtalk_load(hooks(loader)).
```

Check the XML documenting file generated for `object` for the results of the
`term_expansion/2` calls.

Check the results of the `goal_expansion/2` calls:

```logtalk
object::out.
```

<!--
'A'
x(A, A)
3
true.
-->
